@@ -89,21 +89,21 @@ G_BEGIN_DECLS
  *
  * The minor version of the Clutter library (2, if %CLUTTER_VERSION is 1.2.3)
  */
-#define CLUTTER_MINOR_VERSION   (17)
+#define CLUTTER_MINOR_VERSION   (18)
 
 /**
  * CLUTTER_MICRO_VERSION:
  *
  * The micro version of the Clutter library (3, if %CLUTTER_VERSION is 1.2.3)
  */
-#define CLUTTER_MICRO_VERSION   (6)
+#define CLUTTER_MICRO_VERSION   (0)
 
 /**
  * CLUTTER_VERSION:
  *
  * The full version of the Clutter library, like 1.2.3
  */
-#define CLUTTER_VERSION         1.17.6
+#define CLUTTER_VERSION         1.18.0
 
 /**
  * CLUTTER_VERSION_S:
@@ -111,7 +111,7 @@ G_BEGIN_DECLS
  * The full version of the Clutter library, in string form (suited for
  * string concatenation)
  */
-#define CLUTTER_VERSION_S       "1.17.6"
+#define CLUTTER_VERSION_S       "1.18.0"
 
 /**
  * CLUTTER_VERSION_HEX:
@@ -254,21 +254,12 @@ G_BEGIN_DECLS
          (CLUTTER_MAJOR_VERSION == (major) && CLUTTER_MINOR_VERSION > (minor)) || \
          (CLUTTER_MAJOR_VERSION == (major) && CLUTTER_MINOR_VERSION == (minor) && CLUTTER_MICRO_VERSION >= (micro)))
 
-/* annotation for exported variables
- *
- * XXX: this has to be defined here because clutter-macro.h imports this
- * header file.
- */
-#ifdef _MSC_VER
-# ifdef CLUTTER_COMPILATION
-#  define CLUTTER_VAR __declspec(dllexport)
-# else
-#  define CLUTTER_VAR extern __declspec(dllimport)
-# endif
-#else
-# define CLUTTER_VAR extern
+#ifndef _CLUTTER_EXTERN
+#define _CLUTTER_EXTERN extern
 #endif
 
+#define CLUTTER_VAR _CLUTTER_EXTERN
+
 /**
  * clutter_major_version:
  *
@@ -311,12 +302,6 @@ CLUTTER_VAR const guint clutter_minor_version;
  */
 CLUTTER_VAR const guint clutter_micro_version;
 
-gboolean clutter_check_version (guint major,
-                                guint minor,
-                                guint micro);
-
-gboolean clutter_check_windowing_backend (const char *backend_type);
-
 G_END_DECLS
 
 #endif /* __CLUTTER_VERSION_H__ */
