@@ -51,6 +51,7 @@
 #include "clutter-xkb-utils.h"
 #include "clutter-backend-private.h"
 #include "clutter-evdev.h"
+#include "clutter-stage-private.h"
 
 #include "clutter-device-manager-evdev.h"
 
@@ -116,8 +117,9 @@ G_DEFINE_TYPE_WITH_PRIVATE (ClutterDeviceManagerEvdev,
                             clutter_device_manager_evdev,
                             CLUTTER_TYPE_DEVICE_MANAGER)
 
-static ClutterOpenDeviceCallback open_callback;
-static gpointer                  open_callback_data;
+static ClutterOpenDeviceCallback  device_open_callback;
+static ClutterCloseDeviceCallback device_close_callback;
+static gpointer                   device_callback_data;
 
 static const char *device_type_str[] = {
   "pointer",            /* CLUTTER_POINTER_DEVICE */
@@ -572,8 +574,7 @@ clutter_event_dispatch (GSource     *g_source,
         goto out;
 
       /* forward the event into clutter for emission etc. */
-      clutter_do_event (event);
-      clutter_event_free (event);
+      _clutter_stage_queue_event (event->any.stage, event, FALSE);
 
       /* update the device states *after* the event */
       event_state = xkb_state_serialize_mods (seat->xkb, XKB_STATE_MODS_EFFECTIVE);
@@ -635,9 +636,19 @@ clutter_event_source_free (ClutterEventSource *source)
   g_source_unref (g_source);
 }
 
+static void
+clutter_seat_evdev_set_libinput_seat (ClutterSeatEvdev *seat,
+                                      struct libinput_seat *libinput_seat)
+{
+  g_assert (seat->libinput_seat == NULL);
+
+  libinput_seat_ref (libinput_seat);
+  libinput_seat_set_user_data (libinput_seat, seat);
+  seat->libinput_seat = libinput_seat;
+}
+
 static ClutterSeatEvdev *
-clutter_seat_evdev_new (ClutterDeviceManagerEvdev *manager_evdev,
-                        struct libinput_seat *libinput_seat)
+clutter_seat_evdev_new (ClutterDeviceManagerEvdev *manager_evdev)
 {
   ClutterDeviceManager *manager = CLUTTER_DEVICE_MANAGER (manager_evdev);
   ClutterDeviceManagerEvdevPrivate *priv = manager_evdev->priv;
@@ -651,22 +662,13 @@ clutter_seat_evdev_new (ClutterDeviceManagerEvdev *manager_evdev,
   if (!seat)
     return NULL;
 
-  libinput_seat_ref (libinput_seat);
-  libinput_seat_set_user_data (libinput_seat, seat);
-  seat->libinput_seat = libinput_seat;
-
   device = _clutter_input_device_evdev_new_virtual (
     manager, seat, CLUTTER_POINTER_DEVICE);
   _clutter_input_device_set_stage (device, priv->stage);
+  _clutter_input_device_set_coords (device, NULL, INITIAL_POINTER_X, INITIAL_POINTER_Y, NULL);
   _clutter_device_manager_add_device (manager, device);
   seat->core_pointer = device;
 
-  /* Clutter has the notion of global "core" pointers and keyboard devices,
-   * so we need to have a main seat to get them from. Make whatever seat comes
-   * first the main seat. */
-  if (priv->main_seat == NULL)
-    priv->main_seat = seat;
-
   device = _clutter_input_device_evdev_new_virtual (
     manager, seat, CLUTTER_KEYBOARD_DEVICE);
   _clutter_input_device_set_stage (device, priv->stage);
@@ -702,6 +704,7 @@ clutter_seat_evdev_new (ClutterDeviceManagerEvdev *manager_evdev,
   seat->repeat_delay = 250;     /* ms */
   seat->repeat_interval = 33;   /* ms */
 
+  priv->seats = g_slist_append (priv->seats, seat);
   return seat;
 }
 
@@ -722,7 +725,8 @@ clutter_seat_evdev_free (ClutterSeatEvdev *seat)
 
   clear_repeat_timer (seat);
 
-  libinput_seat_unref (seat->libinput_seat);
+  if (seat->libinput_seat)
+    libinput_seat_unref (seat->libinput_seat);
 
   g_free (seat);
 }
@@ -755,8 +759,15 @@ evdev_add_device (ClutterDeviceManagerEvdev *manager_evdev,
   seat = libinput_seat_get_user_data (libinput_seat);
   if (seat == NULL)
     {
-      seat = clutter_seat_evdev_new (manager_evdev, libinput_seat);
-      priv->seats = g_slist_append (priv->seats, seat);
+      /* Clutter has the notion of global "core" pointers and keyboard devices,
+       * which are located on the main seat. Make whatever seat comes first the
+       * main seat. */
+      if (priv->main_seat->libinput_seat == NULL)
+        seat = priv->main_seat;
+      else
+        seat = clutter_seat_evdev_new (manager_evdev);
+
+      clutter_seat_evdev_set_libinput_seat (seat, libinput_seat);
     }
 
   device = _clutter_input_device_evdev_new (manager, seat, libinput_device);
@@ -1115,11 +1126,11 @@ open_restricted (const char *path,
 {
   gint fd;
 
-  if (open_callback)
+  if (device_open_callback)
     {
       GError *error = NULL;
 
-      fd = open_callback (path, flags, open_callback_data, &error);
+      fd = device_open_callback (path, flags, device_callback_data, &error);
 
       if (fd < 0)
         {
@@ -1143,7 +1154,10 @@ static void
 close_restricted (int fd,
                   void *user_data)
 {
-  close (fd);
+  if (device_close_callback)
+    device_close_callback (fd, device_callback_data);
+  else
+    close (fd);
 }
 
 static const struct libinput_interface libinput_interface = {
@@ -1185,14 +1199,9 @@ clutter_device_manager_evdev_constructed (GObject *gobject)
       return;
     }
 
-  dispatch_libinput (manager_evdev);
+  priv->main_seat = clutter_seat_evdev_new (manager_evdev);
 
-  g_assert (priv->main_seat != NULL);
-  g_assert (priv->main_seat->core_pointer != NULL);
-  _clutter_input_device_set_coords (priv->main_seat->core_pointer,
-                                    NULL,
-                                    INITIAL_POINTER_X, INITIAL_POINTER_Y,
-                                    NULL);
+  dispatch_libinput (manager_evdev);
 
   source = clutter_event_source_new (manager_evdev);
   priv->event_source = source;
@@ -1455,8 +1464,9 @@ clutter_evdev_reclaim_devices (void)
 }
 
 /**
- * clutter_evdev_set_open_callback: (skip)
- * @callback: the user replacement for open()
+ * clutter_evdev_set_device_callbacks: (skip)
+ * @open_callback: the user replacement for open()
+ * @close_callback: the user replacement for close()
  * @user_data: user data for @callback
  *
  * Through this function, the application can set a custom callback
@@ -1472,11 +1482,13 @@ clutter_evdev_reclaim_devices (void)
  * Stability: unstable
  */
 void
-clutter_evdev_set_open_callback (ClutterOpenDeviceCallback callback,
-                                 gpointer                  user_data)
+clutter_evdev_set_device_callbacks (ClutterOpenDeviceCallback  open_callback,
+                                    ClutterCloseDeviceCallback close_callback,
+                                    gpointer                   user_data)
 {
-  open_callback = callback;
-  open_callback_data = user_data;
+  device_open_callback = open_callback;
+  device_close_callback = close_callback;
+  device_callback_data = user_data;
 }
 
 /**
