@@ -294,8 +294,7 @@ clutter_event_dispatch (GSource     *source,
   if ((event = clutter_event_get ()))
     {
       /* forward the event into clutter for emission etc. */
-      clutter_do_event (event);
-      clutter_event_free (event);
+      _clutter_stage_queue_event (event->any.stage, event, FALSE);
     }
 
   _clutter_threads_release_lock ();
@@ -571,7 +570,7 @@ clutter_win32_handle_event (const MSG *msg)
             clutter_event_set_device (event, core_pointer);
 
             /* we entered the stage */
-            _clutter_stage_add_device (stage, core_pointer);
+            _clutter_input_device_set_stage (core_pointer, stage);
 
             take_and_queue_event (crossing);
 
@@ -596,7 +595,7 @@ clutter_win32_handle_event (const MSG *msg)
         clutter_event_set_device (event, core_pointer);
 
         /* we left the stage */
-        _clutter_stage_remove_device (stage, core_pointer);
+        _clutter_input_device_set_stage (core_pointer, NULL);
 
         /* When we get a leave message the mouse tracking is
            automatically cancelled so we'll need to start it again when
