@@ -1,6 +1,9 @@
 #include <stdlib.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
 #include <clutter/clutter.h>
+#ifdef CLUTTER_WINDOWING_X11
+#include <clutter/x11/clutter-x11.h>
+#endif
 
 static ClutterActor *
 create_content_actor (void)
@@ -12,7 +15,7 @@ create_content_actor (void)
   content = clutter_actor_new ();
   clutter_actor_set_size (content, 720, 720);
 
-  pixbuf = gdk_pixbuf_new_from_file (TESTS_DATADIR G_DIR_SEPARATOR_S "redhand.png", NULL);
+  pixbuf = gdk_pixbuf_new_from_file ("redhand.png", NULL);
   image = clutter_image_new ();
   clutter_image_set_data (CLUTTER_IMAGE (image),
                           gdk_pixbuf_get_pixels (pixbuf),
@@ -42,13 +45,22 @@ on_pan (ClutterPanAction *action,
         gpointer         *user_data)
 {
   gfloat delta_x, delta_y;
+  const ClutterEvent *event = NULL;
 
   if (is_interpolated)
     clutter_pan_action_get_interpolated_delta (action, &delta_x, &delta_y);
   else
-    clutter_gesture_action_get_motion_delta (CLUTTER_GESTURE_ACTION (action), 0, &delta_x, &delta_y);
+    {
+      clutter_gesture_action_get_motion_delta (CLUTTER_GESTURE_ACTION (action), 0, &delta_x, &delta_y);
+      event = clutter_gesture_action_get_last_event (CLUTTER_GESTURE_ACTION (action), 0);
+    }
 
-  g_print ("panning dx:%.2f dy:%.2f\n", delta_x, delta_y);
+  g_print ("[%s] panning dx:%.2f dy:%.2f\n",
+           event == NULL ? "INTERPOLATED" :
+           event->type == CLUTTER_MOTION ? "MOTION" :
+           event->type == CLUTTER_TOUCH_UPDATE ? "TOUCH UPDATE" :
+           "?",
+           delta_x, delta_y);
 
   return TRUE;
 }
